function y = fRMSE(params,Spot,K,MarketPrice,r,q,T)

% This function returns the objective function described in Equation (30)
% of Madan, Carr, and Chang (1998)

% Fabrice Douglas Rouah, FRouah.com and Volopta.com

sigma = params(1);
v     = params(2);
theta = params(3);
n = length(K);

% Construct the objective function
for i=1:n
    ModelPrice(i) = fVGCall(sigma,v,theta,Spot,K(i),r-q, T);
    error(i) = (log(ModelPrice(i)) - log(MarketPrice(i)))^2;
end

y = sqrt(sum(error)/n);

% Impose a penalty for non-permissible values
if ((sigma < 0) || (v < 0) || ~isreal(y) || isnan(y))
    y = 1e100;
end


